==> healthrian_visualization_support-1.0.10.tar.gz: lib/src/widgets/wear_cardio_t/control_pannel_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support_for_wearcardiot/'
    'healthrian_ble_support_for_wearcardiot.dart';

class ControlPanelWearT extends StatelessWidget {
  const ControlPanelWearT({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().connectDevice();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            BLEManager().lengthBufferStreamEcg = 1;
            BLEManager().maxBufferStreamEcg = 15 * 250;
            await BLEManager().registerCharacteristics();
            await BLEManager().startMeasurementEcg();

            await Future<void>.delayed(
              const Duration(milliseconds: 100),
            );

            BLEManager().lengthBufferStreamOxi = 1;
            BLEManager().maxBufferStreamOxi = 15 * 100;

            await BLEManager().startMeasurementOxi();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().stopMeasurementEcg();
            await BLEManager().stopMeasurementOxi();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().stopMeasurementEcg();
            await BLEManager().stopMeasurementOxi();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () {
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}

==> healthrian_visualization_support-1.0.13.tar.gz: lib/src/widgets/wear_cardio_t/control_pannel_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelWearCardioT extends StatelessWidget {
  const ControlPanelWearCardioT({super.key});

  @override
  Widget build(BuildContext context) {
    BLEManager().setEnable(enableList: [false, false, true]);
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () async {
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          onPressed: () {
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}
